.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "14 December 1996",
.\"     time            = "12:10:22 MST",
.\"     filename        = "sgmlnorm.man",
.\"     address         = "Center for Scientific Computing
.\"                        Department of Mathematics
.\"                        University of Utah
.\"                        Salt Lake City, UT 84112
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     checksum        = "32674 263 944 6853",
.\"     email           = "beebe@math.utah.edu (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "SGML, tag normalizer, WWW",
.\"     supported       = "yes",
.\"     abstract        = "This file is the UNIX manual page for
.\"                        sgmlnorm, an SGML tag normalizer.",
.\"     docstring       = "The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH SGMLNORM 1 "14 December 1996" "Version 1.00"
.\"======================================================================
.SH NAME
sgmlnorm \- normalize SGML tags
.\"======================================================================
.SH SYNOPSIS
.na
.B sgmlnorm
[
.BI \-c " catalog-file"
]
[
.BI \-d " file-directory-name"
]
.RB [ \-e ]
[
.B \-k
.I cm
]
[
.BI \-w " warning_type"
]
.if t .ti +.5i
.if n .ti +9n
[
.I in-sgml-file
or
.RI < in-sgml-file
]
.RI > out-sgml-file
.ad
.\"======================================================================
.SH DESCRIPTION
.B sgmlnorm
is a tag normalizer for SGML files.  It supplies
all omitted optional closing tags, helping to
clarify the scope of each
.I <TAG>
\& .\|.\|.
.I </TAG>
pair.
.PP
.BR spam (1)
is another SGML tag normalizer from the same
software suite.
.\"======================================================================
.SH OPTIONS
.\"-----------------------------------------------
.TP \w'-d_directory-name'u+3n
.BI \-c " catalog-file"
Provide the full path name of the SGML catalog
file, which is needed to relate the document type
name in the initial SGML
.nf
.I "<!DOCTYPE document-type-name PUBLIC ``.\|.\|.\''>"
.fi
declaration to a grammar file that defines the syntax
of the SGML tags in the remainder of the file.
.IP
This option is always required, because
the current version of
.B sgmlnorm
has no built-in default catalog location.
.IP
At some UNIX sites, a suitable option will be
.BI \-c " /usr/local/lib/html-check/lib/catalog"
.\"-----------------------------------------------
.TP
.BI \-d " directory-name"
Add a file directory name to the default search
path used to locate files specified in system
identifiers in
.nf
.I "<!DOCTYPE document-type-name SYSTEM  ``filename''>"
.fi
declarations.  Multiple
.B \-d
options are allowed.
.\"-----------------------------------------------
.TP
.B \-e
Describe open entities in error messages.  Error
messages always include the position of the most
recently opened external entity.
.\"-----------------------------------------------
.TP
.B "\-k cm"
This option requires either
.BR c ,
or
.BR m ,
or both, in either order.
The letter
.B c
requests output of any embedded SGML comments;
otherwise, comments are normally discarded.
The letter
.B m
requests output of marked sections.  [It is
unclear what the
.B m
option is supposed to do.]
.\"-----------------------------------------------
.TP
.BI \-w " warning_type"
Control warnings and errors.
Multiple
.B \-w
options are allowed.
The following values of
.I warning_type
enable warnings:
.RS
.TP \w'unused-param'u+3n
.B mixed
Warn about mixed content models that do not allow
#pcdata anywhere.
.TP
.B sgmldecl
Warn about various dubious constructions in the
SGML declaration.
.TP
.B should
Warn about various recommendations made in ISO
8879 that the document does not comply with.
(Recommendations are expressed with ``should'', as
distinct from requirements which are usually
expressed with ``shall''.)
.TP
.B default
Warn about defaulted references.
.TP
.B duplicate
Warn about duplicate entity declarations.
.TP
.B undefined
Warn about undefined elements: elements used in
the DTD but not defined.
.TP
.B unclosed
Warn about unclosed start and end-tags.
.TP
.B empty
Warn about empty start and end-tags.
.TP
.B net
Warn about net-enabling start-tags and null
end-tags.
.TP
.B min-tag
Warn about minimized start and end-tags.
Equivalent to combination of
.BR unclosed ,
.B empty
and
.B net
warnings.
.TP
.B unused-map
Warn about unused short reference maps: maps that
are declared with a short reference mapping
declaration but never used in a short reference
use declaration in the DTD.
.TP
.B unused-param
Warn about parameter entities that are defined but
not used in a DTD.
.TP
.B all
Warn about conditions that should usually be avoided
(in the opinion of the author).
Equivalent to:
.BR mixed ,
.BR should ,
.BR default ,
.BR undefined ,
.BR sgmldecl ,
.BR unused-map ,
.BR unused-param ,
.B empty
and
.BR unclosed .
.LP
A warning can be disabled by using its name
prefixed with
.BR no- .
Thus
.B -wall\ -wno-duplicate
will enable all warnings except those about
duplicate entity declarations.
.LP
The following values for
.I warning_type
disable errors:
.TP
.B no-idref
Do not give an error for an ID reference value
which no element has as its ID.  The effect will
be as if each attribute declared as an ID
reference value had been declared as a name.
.TP
.B no-significant
Do not give an error when a character that is not
a significant character in the reference concrete
syntax occurs in a literal in the SGML
declaration.  This may be useful in conjunction
with certain buggy test suites.
.RE
.\"======================================================================
.SH "SEE ALSO"
.BR html-check (1),
.BR html-ncheck (1),
.BR html-norm (1),
.BR html-pretty (1),
.BR html-spam (1),
.BR htmlchek (1),
.BR nsgmls (1),
.BR sgmls (1),
.BR spam (1),
.BR spent (1),
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
Department of Mathematics
University of Utah
Salt Lake City, UT 84112
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: <beebe@math.utah.edu>
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
